mohitmishra786/low-level-dev-skills
triton-lang
Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/store, masking, atomics, benchmarking with…
Installation
npx skills add https://github.com/mohitmishra786/low-level-dev-skills
Similar popular skills
Related neighbors and high-traction skills in the same topics — useful to compare before installing.
Converts cuTile GPU kernels (@ct.kernel) to Triton (@triton.jit). Handles standard in-repo conv…
1.5K installs优化 Ascend NPU 亲和的 Triton 算子性能。解决 UB 溢出、提高 Cube 利用率、Tiling 策略设计。关键词…
145 installs根据 Ascend NPU 算子设计文档(或直接需求)生成 Triton kernel 代码。当用户需要实现 Triton 算子、…
139 installs静态检视 Triton 算子代码质量(Host+Device 侧),面向 Ascend NPU。发现潜在 bug、API 误用和性能隐…
135 installsWrite, debug, and optimize Triton and Gluon GPU kernels from local upstream tutorials, producti…
135 installs生成适用于 Ascend NPU 的 Triton 算子需求文档。当用户需要设计新的 Triton 算子、编写算子需求文档…
133 installsAlso in this package
Other skills from mohitmishra786/low-level-dev-skills · top by installs.
npx skills add https://github.com/mohitmishra786/low-level-dev-skills
More details
Agent compatibility
Declared targets from SKILL.md / docs. Unmarked agents are not listed — the skill may still install via the CLI.
Repository health
main
History
- First seen on skills.sh
- First recorded snapshot · 156 installs